/*******************************************************************************
*    Comm2J 1.0.                                                               *
*    Copyright (C) 2004 Luca Bertoncello                                       *
*    Hartigstrae, 12 - 01127 Dresden Deutschland                              *
*    E-Mail: lucabert@lucabert.com, lucabert@lucabert.de                       *
*    http://www.lucabert.com/  http://www.lucabert.de/                         *
*                                                                              *
*    This program is free software; you can redistribute it and/or modify      *
*    it under the terms of the GNU General Public License as published by      *
*    the Free Software Foundation; version 2 of the License.                   *
*                                                                              *
*    This program is distributed in the hope that it will be useful,           *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of            *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
*    GNU General Public License for more details.                              *
*                                                                              *
*    You should have received a copy of the GNU General Public License         *
*    along with this program; if not, write to the Free Software               *
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
*******************************************************************************/

package comm2j;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.IOException;
import java.util.Date;

/**
 * DateMessage is the message class used to send and receive date
 * to/from remote server.<br>
 * @see Comm2J
 * @see java.util.Date
 * @author Luca Bertoncello &lt;lucabert@lucabert.de&gt;
 * @version 1.0
*/

public class DateMessage extends Message
{
  /**
   * Constructor.
   * Initialize the class with null date
   */
  public DateMessage()
  {
    super.className                 = "DateMessage.class";
    super.message                   = null;
  }

  /**
   * Constructor.
   * Initialize the class with given date
   * @param message Initial date
   */
  public DateMessage(Date message)
  {
    super.className                 = "DateMessage.class";
    super.messageHasBeenSet         = true;
    super.message                   = (Object) message;
  }

  /**
   * Send current message throw given OutputStream
   * @param os The OutputStream used to read data
   * @return Number of wrote bytes
   * @throws java.io.IOException if an error occoured
   */
  public int writeMessage(OutputStream os) throws IOException
  {
    DataOutputStream dos;
    String msg;

    dos                             = new DataOutputStream(os);
    msg                             = new Long(((Date) super.message).getTime()).toString();
    Read2J.writeLength(dos, msg.length());
    for(int l = 0; l < msg.length(); l++)
      dos.writeByte(msg.charAt(l));

    return (msg.length() + Read2J.PACKLENGTH);
  }

  /**
   * Sets the internal object.
   * This function is used by readMessage.
   * @param obj Internal object to be set
   */
  protected void setInternalObject(Object obj)
  {
    super.message                   = new Date(Long.parseLong((String) obj));
  }
}
